@@ -34,11 +34,13 @@ from .core.pynebcore import Atom, RecAtom, getAtomDict, getRecEmissivity, Emissi
 from .core.icf import ICF 
 from .core.diags import Diagnostics, diags_dict
 from .core.emisGrid import EmisGrid, getEmisGridDict
+from .core.continuum import Continuum
 from .plot.plotAtomicData import DataPlot
-from .utils.physics import CST
+from .utils.physics import CST, print_IPs
 from .utils.saverestore import save, restore
 from .utils.init import LINE_LABEL_LIST, BLEND_LIST
 from .utils.manage_atomic_data import getLevelsNIST
+from .utils.misc import ROOT_DIR
 from .extinction.red_corr import RedCorr
 
 log_.message('PyNeb ready.', calling='PyNeb')
@@ -51,4 +53,4 @@ Default data dictionary: {}. This set of data can be changed by the user.
 Do not forget to cite the papers corresponding to the atomic data you are using.
 PyNeb website: https://pypi.python.org/pypi/PyNeb
 PyNeb discussion and hotline group email: pyneb@googlegroups.com
-""".format(__version__, atomicData.defaultDict)
\ No newline at end of file
+""".format(__version__, atomicData.defaultDict)
