@@ -17,7 +17,7 @@ class CST(object):
     RYD2ERG = HPLANCK * CLIGHT * RYD
     KCOLLRATE = np.sqrt(2 * PI / BOLTZMANN) * (HPLANCK / (2 * PI))**2 / EMASS**1.5 # constant of collisional rate equation
     BOLTZMANN_eVK = 8.617343e-5 # Boltzmann constant in eV/K
-    
+    RYD_erg =  2.179872325e-11 # HPLANCK * CLIGHT * RYD
     HBETA = 4861.3316598713955
 
 Z = {}
@@ -132,6 +132,7 @@ Z["Sg"] = 106
 Z["Bh"] = 107
 Z["Hs"] = 108
 Z["Mt"] = 109
+Z["Ds"] = 110
 
 Z_inv = {}
 for k in Z.keys():
@@ -409,6 +410,10 @@ gsDict = {
             }
 """
 
+def print_IPs(N_elems=20, N_ions=8):
+    for elem in sorted(IP_tmp, key= lambda x: Z[x])[0:N_elems]: 
+        print('{:<5}'.format(elem), ' '.join(['{:6.2f}'.format(ip) for ip in IP[elem][0:N_ions]])) 
+
 def gsFromAtom(atom, verbose=False):
     """
     atom: eg 'O3' for O++
