@@ -1,12 +1,15 @@
 import numpy as np
 from scipy import interpolate
 import os
+import sys
 import re
 import pyneb as pn
 if pn.config.Chianti_version_main == '8':
     from . import _chianti_tools_8 as _chianti_tools
 elif pn.config.Chianti_version_main == '7':
     from . import _chianti_tools
+elif pn.config.Chianti_version_main == '9':
+    from . import _chianti_tools_9 as _chianti_tools
 from . import _chianti_constants as const
 from .physics import sym2name, vactoair
 from .manage_atomic_data import getLevelsNIST, atom2chianti
@@ -37,9 +40,14 @@ def Chianti_getE(ion_chianti, NLevels=None):
     Es = _chianti_tools.elvlcRead(ion_chianti)
     if not 'j' in Es:
         return None
-    dtype = [('ecmth', '<f8'), ('ionS', 'S10'), ('term', 'S20'),  ('pretty', 'S30'), 
-             ('spd', 'S10'), ('ecm', '<f8'), ('j', '<f8'), ('l', '<i8'), ('erydth', '<f8'), 
-             ('conf', '<i8'), ('lvl', '<i8'), ('spin', '<i8'), ('eryd', '<f8'), ('mult', '<i8')]
+    if sys.version_info.major < 3:
+        dtype = [('ecmth', '<f8'), ('ionS', 'S10'), ('term', 'S20'),  ('pretty', 'S30'), 
+                 ('spd', 'S10'), ('ecm', '<f8'), ('j', '<f8'), ('l', '<i8'), ('erydth', '<f8'), 
+                 ('conf', '<i8'), ('lvl', '<i8'), ('spin', '<i8'), ('eryd', '<f8'), ('mult', '<i8')]
+    else:
+        dtype = [('ecmth', '<f8'), ('ionS', 'U10'), ('term', 'U20'),  ('pretty', 'U30'), 
+                 ('spd', 'U10'), ('ecm', '<f8'), ('j', '<f8'), ('l', '<i8'), ('erydth', '<f8'), 
+                 ('conf', '<i8'), ('lvl', '<i8'), ('spin', '<i8'), ('eryd', '<f8'), ('mult', '<i8')]        
     arr = np.recarray((len(Es['j']),), dtype=dtype)
     for k in Es.keys():
         if k not in ('status', 'ref', 'label', 'filename'):
@@ -134,9 +142,10 @@ def Chianti_getOmega(ion_chianti, tem, lev1=None, lev2=None, Splups=None, NLevel
     pn.log_.debug('NLevels = {}'.format(NLevels), calling='Chianti_getOmega')
     temp=np.asarray(tem)
     if Splups is None:
-        if pn.config.Chianti_version_main == '8':
+        if pn.config.Chianti_version_main == '9':
+            Splups = _chianti_tools.scupsRead(ion_chianti)
+        elif pn.config.Chianti_version_main == '8':
             Splups = _chianti_tools.scupsRead(ion_chianti)
-            print(Splups.keys())
         elif pn.config.Chianti_version_main == '7':
             Splups = _chianti_tools.splupsRead(ion_chianti)
     if NLevels is None:
@@ -172,7 +181,12 @@ def Chianti_getOmega(ion_chianti, tem, lev1=None, lev2=None, Splups=None, NLevel
                     isplups = isplups[0]
                 ttype=Splups["ttype"][isplups]
                 cups=Splups["cups"][isplups]
-                if pn.config.Chianti_version_main == '8':
+                if pn.config.Chianti_version_main == '9':
+                    nspl=Splups["ntemp"][isplups]
+                    dx=1./(float(nspl)-1.)
+                    xs = Splups['btemp'][isplups]
+                    splups=Splups["bscups"][isplups]
+                elif pn.config.Chianti_version_main == '8':
                     nspl=Splups["ntemp"][isplups]
                     dx=1./(float(nspl)-1.)
                     xs = Splups['btemp'][isplups]
@@ -270,7 +284,7 @@ class _AtomChianti(object):
             this_NLevels = None
         else:
             if self.Chianti2NIST is not None:
-                this_NLevels = np.max((self.NLevels, np.max(self.Chianti2NIST.values()[0:self.NLevels])))
+                this_NLevels = np.max((self.NLevels, np.max(list(self.Chianti2NIST.values())[0:self.NLevels])))
             else:
                 this_NLevels = self.NLevels
                 
@@ -457,7 +471,9 @@ class _CollChianti(object):
         self._loadChianti()
         
     def _loadChianti(self):
-        if pn.config.Chianti_version_main == '8':
+        if pn.config.Chianti_version_main == '9':
+            self.fullFileName = _chianti_tools.ion2filename(self.ion_chianti) + '.scups'
+        elif pn.config.Chianti_version_main == '8':
             self.fullFileName = _chianti_tools.ion2filename(self.ion_chianti) + '.scups'
         elif pn.config.Chianti_version_main == '7':
             self.fullFileName = _chianti_tools.ion2filename(self.ion_chianti) + '.splups'
@@ -469,7 +485,9 @@ class _CollChianti(object):
         
         self.Chianti_version = self.collPath.split('/')[-4]
         self.comments = {}
-        if pn.config.Chianti_version_main == '8':
+        if pn.config.Chianti_version_main == '9':
+            self.Splups = _chianti_tools.scupsRead(self.ion_chianti)
+        elif pn.config.Chianti_version_main == '8':
             self.Splups = _chianti_tools.scupsRead(self.ion_chianti)
         elif pn.config.Chianti_version_main == '7':
             self.Splups = _chianti_tools.splupsRead(self.ion_chianti)
@@ -597,7 +615,9 @@ class _CollChianti(object):
         sources = []
         sources.append('Omega-values from {0}'.format(self.Chianti_version))
         
-        if pn.config.Chianti_version_main == '8':
+        if pn.config.Chianti_version_main == '9':
+            refs = _chianti_tools.scupsRead(self.ion_chianti)
+        elif pn.config.Chianti_version_main == '8':
             refs = _chianti_tools.scupsRead(self.ion_chianti)
         elif pn.config.Chianti_version_main == '7':
             refs = _chianti_tools.splupsRead(self.ion_chianti)
