@@ -49,5 +49,8 @@ try:
     import pyfits
     print('pyfits: {0}'.format(pyfits.__version__))
 except:
-    print('NO pyfits')
-
+    try:
+        import astropy.io.fits as pyfits
+        print('pyfits: from astropy')
+    except:
+        pn.log_.error('pyfits not installed')
\ No newline at end of file
